@@ -1,10 +1,10 @@
 ; AisleRiot - bakers_game.scm
 ; Copyright (C) 2001, 2003 Rosanna Yuen <zana@webwynk.net>
 ;
-; This game is free software; you can redistribute it and/or modify
+; This program is free software: you can redistribute it and/or modify
 ; it under the terms of the GNU General Public License as published by
-; the Free Software Foundation; either version 2, or (at your option)
-; any later version.
+; the Free Software Foundation, either version 3 of the License, or
+; (at your option) any later version.
 ;
 ; This program is distributed in the hope that it will be useful,
 ; but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,9 +12,7 @@
 ; GNU General Public License for more details.
 ;
 ; You should have received a copy of the GNU General Public License
-; along with this program; if not, write to the Free Software
-; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
-; USA
+; along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 (def-save-var free-reserves 0)
 
@@ -139,16 +137,26 @@
 	      (deal-cards slot (list f-slot))))
 	(#t (move-to-foundation slot (+ 1 f-slot)))))
 
+(define (autoplay-foundations)
+  (define (autoplay-foundations-tail)
+    (if (or-map button-double-clicked '(4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19))
+        (delayed-call autoplay-foundations-tail)
+        #t))
+  (if (or-map button-double-clicked '(4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19))
+      (autoplay-foundations-tail)
+      #f))
+
 (define (button-double-clicked slot-id)
-  (and (not (empty-slot? slot-id))
-       (> slot-id 3)
-       (or (and (= (get-value (get-top-card slot-id))
-		   ace)
-		(move-to-empty-foundation slot-id 0))
-	   (move-to-foundation slot-id 0))
-       (add-to-score! 1)
-       (or (> slot-id 11)
-	   (set! free-reserves (+ 1 free-reserves)))))
+  (if (> slot-id 3)
+      (and (not (empty-slot? slot-id))
+           (or (and (= (get-value (get-top-card slot-id))
+		       ace)
+		    (move-to-empty-foundation slot-id 0))
+	       (move-to-foundation slot-id 0))
+           (add-to-score! 1)
+           (or (> slot-id 11)
+	       (set! free-reserves (+ 1 free-reserves))))
+       (autoplay-foundations)))
 
 (define (game-continuable)
   (and (not (game-won))
